Optional: Join an IRC Room
==========================

The Matrix community maintains bridges to most major IRC networks.
You can use the same Matrix account and client to join IRC channels as
well as Zuul's Matrix Room.  You will benefit from the persistent
connection and history features as well.  Follow the instructions
below to join an IRC channel.  The example below is for the
``#opendev`` channel on OFTC, but the process is similar for other
channels or networks.

Click the plus icon next to `Rooms` on the left of the screen, then
click `Explore public rooms` in the dropdown that appears.

.. image:: /images/matrix/account-rooms-dropdown.png
   :align: center

A popup dialog will appear; below the search bar in the dialog, click
the dropdown selector labeled `Matrix rooms (matrix.org)` and change
it to `OFTC rooms (matrix.org)`.  Then enter ``#opendev`` into the search
box.

.. image:: /images/matrix/account-rooms-opendev.png
   :align: center

It will display `No results for "#opendev"` which is an unfortunate
consequence of one of the anti-spam measures that is necessary on IRC.
Disregard that and hit `enter` or click `Join`, and you will join the
room.

If this is your first time joining an OFTC channel, you will also
receive an invitation to join the `OFTC IRC Bridge status` room.

.. image:: /images/matrix/account-rooms-invite.png
   :align: center

Accept the invitation.

.. image:: /images/matrix/account-rooms-accept.png
   :align: center

This is a private control channel between you and the system that
operates the OFTC bridge.  Here you can perform some IRC commands such
as changing your nickname and setting up nick registration.  That is
out of scope for this HOWTO, but advanced IRC users may be interested
in doing so.

You may repeat this procedure for any other IRC channels on the OFTC,
Freenode, or libera.chat networks.
